@@ -715,7 +715,7 @@ class Migrate(_Staff, _Confirm, Call):
     @classmethod
     def iarguments(cls):
         yield Source(["source"])
-        yield Distribution(["distribution"], choices=values.Name.MIGRATABLE_DISTRIBUTIONS)
+        yield Distribution(["distribution"], choices=values.Name.MIGRATABLE_DISTRIBUTIONS, extra_doc="\n\nMigrates *from* this distribution")
         yield BoolArgument(["--full", "-F"], doc="Migrate all 'migrates_to' suites up (f.e. unstable->testing->stable)")
         yield StrArgument(["--version", "-V"], default="", doc=f"Migrate exactly this version. {MULT_VERSIONS_PER_DIST_NOTE}")
 
